==> OSCA.multisample_1.10.4.tar.gz: OSCA.multisample/inst/doc/book/index.md <==
--- 
title: "Multi-Sample Single-Cell Analyses with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.18-bioc/R/site-library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.multisample"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Alan O'Callaghan [cre]<br/>
  **Version:** 1.10.4<br/>
  **Modified:** 2024-02-15<br/>
  **Compiled:** 2024-02-16<br/>
  **Environment:** R version 4.3.2 Patched (2023-11-13 r85521), Bioconductor 3.18<br/>
  **License:** CC BY<br/>
  **Copyright:** Bioconductor, 2024<br/>
  **Source:** https://github.com/OSCA-source/OSCA.multisample"
url: "https://github.com/OSCA-source/OSCA.multisample"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the advanced analysis chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.18/OSCA).
This describes the handling of multiple samples in a single-cell RNA-seq analysis, 
    starting with integration of multiple datasets into a common space for consistent analyses,
    differential expression comparisons between conditions based on pseudo-bulk samples,
    and differential abundance analyses for cell subpopulations. It is intended for readers who are already familiar with basic single-cell analyses, possibly after reading some of the prior books in this collection.

==> OSCA.multisample_1.12.0.tar.gz: OSCA.multisample/inst/doc/book/index.md <==
--- 
title: "Multi-Sample Single-Cell Analyses with Bioconductor"
documentclass: book
bibliography: ref.bib
biblio-style: apalike
link-citations: yes
favicon: "/home/biocbuild/bbs-3.19-bioc/R/site-library/rebook/images/favicon.ico"
github-repo: "OSCA-source/OSCA.multisample"
---



---
date: "**Authors:** Robert Amezquita [aut], Aaron Lun [aut], Stephanie Hicks [aut], Raphael Gottardo [aut], Alan O'Callaghan [cre]<br/>
  **Version:** 1.12.0<br/>
  **Modified:** 2024-04-19<br/>
  **Compiled:** 2024-05-01<br/>
  **Environment:** R version 4.4.0 beta (2024-04-15 r86425), Bioconductor 3.19<br/>
  **License:** CC BY<br/>
  **Copyright:** Bioconductor, 2024<br/>
  **Source:** https://github.com/OSCA-source/OSCA.multisample"
url: "https://github.com/OSCA-source/OSCA.multisample"
---

# Welcome {-}

<a href="https://bioconductor.org"><img src="https://github.com/Bioconductor/BiocStickers/raw/master/Bioconductor/Bioconductor-serial.gif" width="200" alt="Bioconductor Sticker" align="right" style="margin: 0 1em 0 1em" /></a> 

This site contains the advanced analysis chapters for the [__"Orchestrating Single-Cell Analysis with Bioconductor"__ book](http://bioconductor.org/books/3.19/OSCA).
This describes the handling of multiple samples in a single-cell RNA-seq analysis, 
    starting with integration of multiple datasets into a common space for consistent analyses,
    differential expression comparisons between conditions based on pseudo-bulk samples,
    and differential abundance analyses for cell subpopulations. It is intended for readers who are already familiar with basic single-cell analyses, possibly after reading some of the prior books in this collection.
